@@ -383,6 +383,10 @@
                       PenalizedLDA = data.frame(.lambda = 10 ^ seq(-1, -4, length = len), .K = length(levels(data$.outcome)) - 1),
                       xyf =, bdk = somDims(len),
                       rFerns = data.frame(.depth = unique(floor(seq(1, 16, length = len)))),
+                      mlp = data.frame(.size =  ((1:len) * 2) - 1),
+                      mlpWeightDecay = data.frame(.size =  ((1:len) * 2) - 1, .decay = c(0, 10 ^ seq(-1, -4, length = len - 1))),
+                      rbf = data.frame(.size =  ((1:len) * 2) + 9),
+                      rbfDDA = data.frame(.negativeThreshold =  10 ^(-(1:len))),
                       lda =, lm =, treebag =, sddaLDA =, sddaQDA =,
                       glm =, qda =, OneR =, rlm =,
                       rvmLinear =, lssvmLinear =, gaussprLinear =,
