@@ -66,7 +66,8 @@
                    'smda', 'sparseLDA', 'spls', 'stepLDA', 'stepQDA',
                    'superpc', 'svmLinear', 'svmpoly', 'svmPoly',
                    'svmradial', 'svmRadial', 'svmRadialCost', 'rFerns',
-                   'vbmpRadial', 'widekernelpls', 'PenalizedLDA'))
+                   'vbmpRadial', 'widekernelpls', 'PenalizedLDA',
+                   "mlp", "mlpWeightDecay", "rbf", "rbfDDA"))
     {
       trainX <- data[,!(names(data) %in% ".outcome"), drop = FALSE]
       trainY <- data[,".outcome"]
@@ -1833,7 +1834,100 @@
                            contin = !is.factor(trainY),
                            grid = somgrid(tuneValue$.xdim, tuneValue$.ydim, tuneValue$.topo),
                            ...)
-                     },                     
+                     },
+                     mlp =
+                     {
+                       library(RSNNS)
+                       theDots <- list(...)
+                       theDots <- theDots[!(names(theDots) %in% c("size", "linOut"))]                   
+
+                       if(is.factor(trainY)) trainY <- decodeClassLabels(trainY)
+                       args <- list(x = trainX,
+                                    y = trainY,
+                                    size = tuneValue$.size,
+                                    linOut = is.na(obsLevels))
+                       args <- c(args, theDots)
+                       do.call("mlp", args)
+                     },
+                     mlpWeightDecay =
+                     {
+                       library(RSNNS)
+                       theDots <- list(...)
+                       theDots <- theDots[!(names(theDots) %in% c("size", "linOut"))]
+                       if(any(names(theDots) == "learnFunc"))
+                         {
+                           theDots$learnFunc <- NULL
+                           warning("Cannot over-ride 'learnFunc' argument for this model. BackpropWeightDecay is used.")
+                         }
+                       if(any(names(theDots) == "learnFuncParams"))
+                         {
+                           prms <- theDots$learnFuncParams
+                           prms[3] <-  tuneValue$.decay
+                           warning("Over-riding weight decay value in the 'learnFuncParams' argument you passed in. Other values are retained")
+                         } else prms <- c(0.2, tuneValue$.decay, 0.0, 0.0)    
+
+                       if(is.factor(trainY)) trainY <- decodeClassLabels(trainY)
+                       args <- list(x = trainX,
+                                    y = trainY,
+                                    learnFunc = "BackpropWeightDecay",
+                                    learnFuncParams = prms,                                
+                                    size = tuneValue$.size,
+                                    linOut = is.na(obsLevels))
+                       args <- c(args, theDots)
+                       do.call("mlp", args)
+                     },
+                     rbf =
+                     {
+                       library(RSNNS)
+                       theDots <- list(...)
+                       theDots <- theDots[!(names(theDots) %in% c("size", "linOut"))]
+                       if(any(names(theDots) == "learnFunc"))
+                         {
+                           theDots$learnFunc <- NULL
+                           warning("Cannot over-ride 'learnFunc' argument for this model. RadialBasisLearning is used.")
+                         }
+                       if(!any(names(theDots) == "initFuncParams"))
+                         {
+                           theDots$initFuncParams <- c(0, 1, 0, 0.02, 0.04)
+                           if(is.factor(trainY)) theDots$initFuncParams[1:2] <- c(-4, 4)
+                         }
+                       
+                       if(!any(names(theDots) == "learnFuncParams"))
+                         {
+                           theDots$learnFuncParams <- c(1e-8, 0, 1e-8, 0.1, 0.8)
+                         }
+                      
+
+                       if(is.factor(trainY)) trainY <- decodeClassLabels(trainY)
+                       args <- list(x = trainX,
+                                    y = trainY,                           
+                                    size = tuneValue$.size,
+                                    linOut = is.na(obsLevels))
+                       args <- c(args, theDots)
+                       do.call("rbf", args)
+                     },
+                     rbfDDA =
+                     {
+                       library(RSNNS)
+                       theDots <- list(...)
+                      
+                       if(any(names(theDots) == "learnFunc"))
+                         {
+                           theDots$learnFunc <- NULL
+                           warning("Cannot over-ride 'learnFunc' argument for this model. RBF-DDA is used.")
+                         }
+                       if(any(names(theDots) == "learnFuncParams"))
+                         {
+                           theDots$learnFuncParams[2] <- tuneValue$.negativeThreshold
+                         } else theDots$learnFuncParams <-c(0.4,  tuneValue$.negativeThreshold, 5)
+                       
+
+                       trainY <- decodeClassLabels(trainY)
+                       args <- list(x = trainX,
+                                    y = trainY)
+                       args <- c(args, theDots)
+                       do.call("rbfDDA", args)
+                     },                                           
                      custom =
                      {
                        custom(data = data,
